@@ -1,6 +1,6 @@
 # TODO - figure out how to use files as templates
 
-TEMPLATE = '''<!DOCTYPE html>
+TEMPLATE = """<!DOCTYPE html>
 
 <html>
 
@@ -8,9 +8,10 @@ TEMPLATE = '''<!DOCTYPE html>
   <meta charset=utf-8 />
   <meta name="viewport" content="user-scalable=no, initial-scale=1.0, minimum-scale=1.0, maximum-scale=1.0, minimal-ui">
   <title>GraphQL Playground</title>
-  <link rel="stylesheet" href="/vendor/graphql-playground/index.css" />
-  <link rel="shortcut icon" href="/vendor/graphql-playground/favicon.png" />
-  <script src="/vendor/graphql-playground/middleware.js"></script>
+  <!-- Jinja templating -->
+  <link rel="stylesheet" href="{{ app_path_prefix }}/vendor/graphql-playground/index.css" />
+  <link rel="shortcut icon" href="{{ app_path_prefix }}/vendor/graphql-playground/favicon.png" />
+  <script src="{{ app_path_prefix }}/vendor/graphql-playground/middleware.js"></script>
 
 </head>
 
@@ -534,9 +535,13 @@ TEMPLATE = '''<!DOCTYPE html>
       root.classList.add('playgroundIn');
 
       GraphQLPlayground.init(root, {
-        subscriptionEndpoint: 'ws://' + document.location.host + document.location.pathname
+        subscriptionEndpoint: 'ws://' + document.location.host + document.location.pathname,
+        settings: {
+          'schema.polling.enable': false,
+          'request.credentials': 'same-origin',
+        }
       })
     })
   </script>
 </body>
-</html>'''
+</html>"""
